@@ -6,24 +6,22 @@
 #' \cr\cr
 #' Both Cohen's *d* and Hedges' *g* are the estimated the standardized
 #' difference between the means of two populations. Hedges' *g* provides a bias
-#' correction to Cohen's *d* for small sample sizes. For sample sizes > 20, the
-#' results for both statistics are roughly equivalent. Glass’s *delta* is
-#' appropriate when the standard deviations are significantly different between
-#' the populations, as it uses only the *second* group's standard deviation.
+#' correction (using the exact method) to Cohen's *d* for small sample sizes.
+#' For sample sizes > 20, the results for both statistics are roughly
+#' equivalent. Glass’s *delta* is appropriate when the standard deviations are
+#' significantly different between the populations, as it uses only the *second*
+#' group's standard deviation.
 #'
 #' @param x A formula, a numeric vector, or a character name of one in `data`.
 #' @param y A numeric vector, a grouping (character / factor) vector, a or a
 #'   character  name of one in `data`. Ignored if `x` is a formula.
 #' @param data An optional data frame containing the variables.
-#' @param correction Type of small sample bias correction to apply to produce
-#'   Hedges' *g*. Can be `1` for Hedges and Olkin's original correction
-#'   (default) or `2` for Hunter and Schmidt's correction (see McGrath & Meyer,
-#'   2006).
 #' @param pooled_sd If `TRUE` (default), a [sd_pooled()] is used (assuming equal
 #'   variance). Else the mean SD from both groups is used instead.
 #' @param paired If `TRUE`, the values of `x` and `y` are considered as paired.
 #'   This produces an effect size that is equivalent to the one-sample effect
 #'   size on `x - y`.
+#' @param iterations,correction deprecated.
 #' @inheritParams chisq_to_phi
 #' @inheritParams eta_squared
 #' @inheritParams stats::t.test
@@ -33,12 +31,11 @@
 #'   applying Bessel's correction).
 #'
 #' @details
-#'
-#' ## Confidence Intervals for Glass' *delta*
-#' Confidence Intervals for Glass' *delta* are estimated using the bootstrap
-#' method.
+#' Set `pooled_sd = FALSE` for effect sizes that are to accompany a Welch's
+#' *t*-test (Delacre et al, 2021).
 #'
 #' @inheritSection effectsize-CIs Confidence Intervals
+#' @inheritSection effectsize-CIs CI Contains Zero
 #'
 #' @return A data frame with the effect size ( `Cohens_d`, `Hedges_g`,
 #'   `Glass_delta`) and their CIs (`CI_low` and `CI_high`).
@@ -55,13 +52,15 @@
 #' cohens_d(mpg ~ am, data = mtcars, pooled_sd = FALSE)
 #' cohens_d(mpg ~ am, data = mtcars, mu = -5)
 #' hedges_g(mpg ~ am, data = mtcars)
-#' if (require(boot)) glass_delta(mpg ~ am, data = mtcars)
+#' glass_delta(mpg ~ am, data = mtcars)
 #' print(cohens_d(mpg ~ am, data = mtcars), append_CL = TRUE)
 #'
 #' # other acceptable ways to specify arguments
-#' cohens_d(sleep$extra, sleep$group)
+#' glass_delta(sleep$extra, sleep$group)
 #' hedges_g("extra", "group", data = sleep)
 #' cohens_d(sleep$extra[sleep$group == 1], sleep$extra[sleep$group == 2], paired = TRUE)
+#' # cohens_d(Pair(extra[group == 1], extra[group == 2]) ~ 1,
+#' #          data = sleep, paired = TRUE)
 #'
 #' # one-sample tests -----------------------
 #'
@@ -75,18 +74,23 @@
 #' interpret_g(0.4, rules = "sawilowsky2009")
 #' interpret_delta(0.4, rules = "gignac2016")
 #' @references
+#' - Algina, J., Keselman, H. J., & Penfield, R. D. (2006). Confidence intervals
+#' for an effect size when variances are not equal. Journal of Modern Applied
+#' Statistical Methods, 5(1), 2.
+#'
 #' - Cohen, J. (1988). Statistical power analysis for the behavioral
 #' sciences (2nd Ed.). New York: Routledge.
 #'
+#' - Delacre, M., Lakens, D., Ley, C., Liu, L., & Leys, C. (2021, May 7). Why
+#' Hedges’ g*s based on the non-pooled standard deviation should be reported
+#' with Welch's t-test. https://doi.org/10.31234/osf.io/tu6mp
+#'
 #' - Hedges, L. V. & Olkin, I. (1985). Statistical methods for
 #' meta-analysis. Orlando, FL: Academic Press.
 #'
 #' - Hunter, J. E., & Schmidt, F. L. (2004). Methods of meta-analysis:
 #' Correcting error and bias in research findings. Sage.
 #'
-#' - McGrath, R. E., & Meyer, G. J. (2006). When effect sizes disagree: the
-#' case of r and d. Psychological methods, 11(4), 386.
-#'
 #' @importFrom stats var model.frame
 #' @export
 cohens_d <- function(x,
@@ -97,19 +101,12 @@ cohens_d <- function(x,
                      paired = FALSE,
                      ci = 0.95,
                      verbose = TRUE,
-                     ...,
-                     correction) {
-  if (!missing(correction)) {
-    warning("`correction` argument is deprecated. To apply bias correction, use `hedges_g()`.",
-      call. = FALSE, immediate. = TRUE
-    )
-  }
-
+                     ...) {
   if (inherits(x, "htest")) {
     if (!grepl("t-test", x$method)) {
       stop("'x' is not a t-test!", call. = FALSE)
     }
-    return(effectsize(x, type = "d", correction = correction, ci = ci, verbose = verbose))
+    return(effectsize(x, type = "d", ci = ci, verbose = verbose))
   } else if (inherits(x, "BFBayesFactor")) {
     if (!inherits(x@numerator[[1]], c("BFoneSample", "BFindepSample"))) {
       stop("'x' is not a t-test!", call. = FALSE)
@@ -132,30 +129,28 @@ cohens_d <- function(x,
 }
 
 #' @rdname cohens_d
-#' @param iterations The number of bootstrap replicates for computing confidence intervals. Only applies when \code{ci} is not \code{NULL}.
 #' @export
 hedges_g <- function(x,
                      y = NULL,
                      data = NULL,
-                     correction = 1,
                      pooled_sd = TRUE,
                      mu = 0,
                      paired = FALSE,
                      ci = 0.95,
                      verbose = TRUE,
-                     ...) {
-  if (isTRUE(correction) || !correction %in% c(1, 2)) {
-    warning("`correction` must be 1 or 2. See ?hedges_g. Setting to 1 for Hedges & Olkin's correction.",
+                     ...,
+                     correction) {
+  if (!missing(correction)) {
+    warning("`correction` argument is deprecated. *Exact* bias correction method is used.",
       call. = FALSE, immediate. = TRUE
     )
-    correction <- 1
   }
 
   if (inherits(x, "htest")) {
     if (!grepl("t-test", x$method)) {
       stop("'x' is not a t-test!", call. = FALSE)
     }
-    return(effectsize(x, type = "g", correction = correction, ci = ci, verbose = verbose))
+    return(effectsize(x, type = "g", ci = ci, verbose = verbose))
   } else if (inherits(x, "BFBayesFactor")) {
     if (!inherits(x@numerator[[1]], c("BFoneSample", "BFindepSample"))) {
       stop("'x' is not a t-test!", call. = FALSE)
@@ -168,7 +163,6 @@ hedges_g <- function(x,
     y = y,
     data = data,
     type = "g",
-    correction = correction,
     pooled_sd = pooled_sd,
     mu = mu,
     paired = paired,
@@ -184,12 +178,11 @@ glass_delta <- function(x,
                         data = NULL,
                         mu = 0,
                         ci = 0.95,
-                        iterations = 200,
                         verbose = TRUE,
                         ...,
-                        correction) {
-  if (!missing(correction)) {
-    warning("`correction` argument is deprecated. To apply bias correction, use `hedges_g()`.",
+                        iterations) {
+  if (!missing(iterations)) {
+    warning("`iterations` argument is deprecated. Parametric CIs are estimated.",
       call. = FALSE, immediate. = TRUE
     )
   }
@@ -201,8 +194,7 @@ glass_delta <- function(x,
     mu = mu,
     type = "delta",
     ci = ci,
-    verbose = verbose,
-    iterations = iterations
+    verbose = verbose
   )
 }
 
@@ -215,12 +207,10 @@ glass_delta <- function(x,
                                     data = NULL,
                                     type = "d",
                                     mu = 0,
-                                    correction = NULL,
                                     pooled_sd = TRUE,
                                     paired = FALSE,
                                     ci = 0.95,
                                     verbose = TRUE,
-                                    iterations = NULL,
                                     ...) {
   out <- .deal_with_cohens_d_arguments(x, y, data, verbose)
   x <- out$x
@@ -254,22 +244,23 @@ glass_delta <- function(x,
     y <- stats::na.omit(y)
 
     d <- mean(x) - mean(y)
+
+    s1 <- stats::sd(x)
+    s2 <- stats::sd(y)
+
     n1 <- length(x)
     n2 <- length(y)
     n <- n1 + n2
 
     if (type %in% c("d", "g")) {
-      hn <- (1 / n1 + 1 / n2)
       if (pooled_sd) {
         s <- suppressWarnings(sd_pooled(x, y))
-
+        hn <- (1 / n1 + 1 / n2)
         se <- s * sqrt(1 / n1 + 1 / n2)
         df <- n - 2
       } else {
-        s1 <- stats::sd(x)
-        s2 <- stats::sd(y)
         s <- sqrt((s1^2 + s2^2) / 2)
-
+        hn <- (2 * (n2 * s1^2 + n1 * s2^2)) / (n1 * n2 * (s1^2 + s2^2))
         se1 <- sqrt(s1^2 / n1)
         se2 <- sqrt(s2^2 / n2)
         se <- sqrt(se1^2 + se2^2)
@@ -277,7 +268,11 @@ glass_delta <- function(x,
       }
     } else if (type == "delta") {
       pooled_sd <- NULL
-      s <- stats::sd(y)
+
+      s <- s2
+      hn <- 1 / n2 + s1^2 / (n1 * s2^2)
+      se <- (s2 * sqrt(1 / n2 + s1^2 / (n1 * s2^2)))
+      df <- n2 - 1
     }
   }
 
@@ -290,38 +285,19 @@ glass_delta <- function(x,
     stopifnot(length(ci) == 1, ci < 1, ci > 0)
 
     # Add cis
-    if (type %in% c("d", "g")) {
-      out$CI <- ci
+    out$CI <- ci
 
-      t <- (d - mu) / se
-      ts <- .get_ncp_t(t, df, ci)
+    t <- (d - mu) / se
+    ts <- .get_ncp_t(t, df, ci)
 
-      out$CI_low <- ts[1] * sqrt(hn)
-      out$CI_high <- ts[2] * sqrt(hn)
-      ci_method <- list(method = "ncp", distribution = "t")
-    } else if (type == "delta") {
-      if (requireNamespace("boot", quietly = TRUE)) {
-        out <- cbind(out, .delta_ci(x, y, mu = mu, ci = ci, ...))
-        ci_method <- list(method = "bootstrap", iterations = iterations)
-      } else {
-        ci <- NULL
-        warning("'boot' package required for estimating CIs for Glass' delta. Please install the package and try again.", call. = FALSE)
-      }
-    }
+    out$CI_low <- ts[1] * sqrt(hn)
+    out$CI_high <- ts[2] * sqrt(hn)
+    ci_method <- list(method = "ncp", distribution = "t")
   }
 
 
   if (type == "g") {
-    if (correction == 1) {
-      if (paired) {
-        J <- 1 - 3 / (4 * (n - 1) - 1)
-      } else {
-        J <- 1 - 3 / (4 * n - 9)
-      }
-    } else if (correction == 2) {
-      # McGrath & Meyer (2006)
-      J <- ((n - 3) / (n - 2.25)) * sqrt((n - 2) / n)
-    }
+    J <- exp(lgamma(df / 2) - log(sqrt(df / 2)) - lgamma((df - 1) / 2)) # exact method
 
     out[, colnames(out) %in% c("Hedges_g", "CI_low", "CI_high")] <-
       out[, colnames(out) %in% c("Hedges_g", "CI_low", "CI_high")] * J
@@ -329,7 +305,7 @@ glass_delta <- function(x,
 
   class(out) <- c("effectsize_difference", "effectsize_table", "see_effectsize_table", class(out))
   attr(out, "paired") <- paired
-  attr(out, "correction") <- correction
+  attr(out, "correction") <- type == "g" # Don't actually need this
   attr(out, "pooled_sd") <- pooled_sd
   attr(out, "mu") <- mu
   attr(out, "ci") <- ci
@@ -408,6 +384,7 @@ glass_delta <- function(x,
       }
 
       data <- split(x, y)
+      data <- Filter(length, data)
       x <- data[[1]]
       y <- data[[2]]
     } else if (verbose && length(unique(y)) == 2) {
@@ -425,31 +402,31 @@ glass_delta <- function(x,
   list(x = x, y = y)
 }
 
-.delta_ci <- function(x, y, mu = 0, ci = 0.95, iterations = 200) {
-  boot_delta <- function(data, .i, mu = 0) {
-    .x <- sample(x, replace = TRUE)
-    .y <- sample(y, replace = TRUE)
-
-    d <- mean(.x) - mean(.y)
-    s <- stats::sd(.y)
-    (d - mu) / s
-  }
-
-  # dud, not actually used
-  data <- data.frame(
-    i = seq_along(c(x, y))
-  )
-
-  R <- boot::boot(
-    data = data,
-    statistic = boot_delta,
-    R = iterations,
-    mu = mu
-  )
-
-  out <- as.data.frame(
-    bayestestR::ci(na.omit(R$t), ci = ci, verbose = FALSE)
-  )
-  out$CI <- ci
-  out
-}
+# .delta_ci <- function(x, y, mu = 0, ci = 0.95, iterations = 200) {
+#   boot_delta <- function(data, .i, mu = 0) {
+#     .x <- sample(x, replace = TRUE)
+#     .y <- sample(y, replace = TRUE)
+#
+#     d <- mean(.x) - mean(.y)
+#     s <- stats::sd(.y)
+#     (d - mu) / s
+#   }
+#
+#   # dud, not actually used
+#   data <- data.frame(
+#     i = seq_along(c(x, y))
+#   )
+#
+#   R <- boot::boot(
+#     data = data,
+#     statistic = boot_delta,
+#     R = iterations,
+#     mu = mu
+#   )
+#
+#   out <- as.data.frame(
+#     bayestestR::ci(na.omit(R$t), ci = ci, verbose = FALSE)
+#   )
+#   out$CI <- ci
+#   out
+# }
