@@ -25,11 +25,11 @@
 #' @return Converted index.
 #'
 #' @details
-#' Conversions between *OR* and *r* is done through these formulae.
-#' - *d to r*: \eqn{d = \frac{2 * r}{\sqrt{1 - r^2}}}
-#' - *r to d*: \eqn{r = \frac{d}{\sqrt{d^2 + 4}}}
-#' - *OR to d*: \eqn{d = \frac{\log(OR)\times\sqrt{3}}{\pi}}
-#' - *d to OR*: \eqn{log(OR) = d * \frac{\pi}{\sqrt(3)}}
+#' Conversions between *d* and *OR* or *r* is done through these formulae.
+#' - \eqn{d = \frac{2 * r}{\sqrt{1 - r^2}}}{d = 2 * r / sqrt(1 - r^2)}
+#' - \eqn{r = \frac{d}{\sqrt{d^2 + 4}}}{r = d / sqrt(d^2 + 4)}
+#' - \eqn{d = \frac{\log(OR)\times\sqrt{3}}{\pi}}{d = log(OR) * sqrt(3) / pi}
+#' - \eqn{log(OR) = d * \frac{\pi}{\sqrt(3)}}{log(OR) = d * pi / sqrt(3)}
 #'
 #' The conversion from *d* to *r* assumes equally sized groups. The resulting
 #' *r* is also called the binomial effect size display (BESD; Rosenthal et al.,
@@ -44,28 +44,29 @@
 #' (2009). Converting among effect sizes. Introduction to meta-analysis, 45-49.
 #'
 #' - Rosenthal, R., & Rubin, D. B. (1982). A simple, general purpose display of
-#' magnitude of experimental effect. Journal of educational psychology, 74(2),
-#' 166.
+#' magnitude of experimental effect. Journal of educational psychology, 74(2), 166.
 #'
 #' @export
+#' @aliases convert_d_to_r
 d_to_r <- function(d, ...) {
   d / (sqrt(d^2 + 4))
 }
 
+#' @export
+convert_d_to_r <- d_to_r
+
+
+
+
+
 
 #' @rdname d_to_r
+#' @aliases convert_r_to_d
 #' @export
 r_to_d <- function(r, ...) {
   2 * r / sqrt(1 - r^2)
 }
 
-
-
-#' @rdname d_to_r
-#' @export
-convert_d_to_r <- d_to_r
-
-#' @rdname d_to_r
 #' @export
 convert_r_to_d <- r_to_d
 
@@ -73,9 +74,8 @@ convert_r_to_d <- r_to_d
 
 # OR - d ----------------------------------------------------------------
 
-
-
 #' @rdname d_to_r
+#' @aliases convert_oddsratio_to_d
 #' @export
 oddsratio_to_d <- function(OR, log = FALSE, ...) {
   if (log) {
@@ -87,19 +87,25 @@ oddsratio_to_d <- function(OR, log = FALSE, ...) {
   log_OR * (sqrt(3) / pi)
 }
 
-#' @rdname d_to_r
 #' @export
 convert_oddsratio_to_d <- oddsratio_to_d
 
+
+
 #' @rdname d_to_r
+#' @aliases convert_logoddsratio_to_d
 #' @export
 logoddsratio_to_d <- function(OR, log = TRUE, ...) {
   oddsratio_to_d(OR, log = log, ...)
 }
 
+#' @export
+convert_logoddsratio_to_d <- logoddsratio_to_d
+
 
 
 #' @rdname d_to_r
+#' @aliases convert_d_to_oddsratio
 #' @export
 d_to_oddsratio <- function(d, log = FALSE, ...) {
   log_OR <- d * pi / sqrt(3)
@@ -111,7 +117,6 @@ d_to_oddsratio <- function(d, log = FALSE, ...) {
   }
 }
 
-#' @rdname d_to_r
 #' @export
 convert_d_to_oddsratio <- d_to_oddsratio
 
@@ -121,29 +126,33 @@ convert_d_to_oddsratio <- d_to_oddsratio
 # OR - r ----------------------------------------------------------------
 
 #' @rdname d_to_r
+#' @aliases convert_oddsratio_to_r
 #' @export
 oddsratio_to_r <- function(OR, log = FALSE, ...) {
   d_to_r(oddsratio_to_d(OR, log = log))
 }
 
-#' @rdname d_to_r
 #' @export
 convert_oddsratio_to_r <- oddsratio_to_r
 
 #' @rdname d_to_r
+#' @aliases convert_logoddsratio_to_r
 #' @export
 logoddsratio_to_r <- function(OR, log = TRUE, ...) {
   oddsratio_to_r(OR, log = log, ...)
 }
 
+#' @export
+convert_logoddsratio_to_r <- logoddsratio_to_r
+
 
 
 #' @rdname d_to_r
+#' @aliases convert_r_to_oddsratio
 #' @export
 r_to_oddsratio <- function(r, log = FALSE, ...) {
   d_to_oddsratio(r_to_d(r), log = log)
 }
 
-#' @rdname d_to_r
 #' @export
 convert_r_to_oddsratio <- r_to_oddsratio
