@@ -422,9 +422,8 @@ standardize_info <- function(model, robust = FALSE, two_sd = FALSE, include_pseu
   ## Get 2 types of Deviation_Response_Pseudo
   sd_y_within <- sd_y_between <- 1
   if (insight::model_info(model)$is_linear) {
-    if (!requireNamespace("lme4", quietly = TRUE)) {
-      stop("This function requires 'lme4' to work.", call. = FALSE)
-    }
+    check_if_installed("lme4")
+
     rand_name <- insight::find_random(model)$random
 
     # maintain any y-transformations
