@@ -178,7 +178,7 @@ standardize_parameters.default <- function(model, method = "refit", ci = 0.95, r
 
   # need model_parameters to return the parameters, not the terms
   if (inherits(model, "aov")) class(model) <- class(model)[class(model) != "aov"]
-  pars <- parameters::model_parameters(model, ci = ci, standardize = NULL, ...)
+  pars <- parameters::model_parameters(model, ci = ci, standardize = NULL, effects = "fixed", ...)
 
   # should post hoc exponentiate?
   dots <- list(...)
