@@ -1,22 +1,15 @@
 if (require("testthat") && require("effectsize")) {
   test_that("rank_biserial", {
-    skip_if_not_installed("boot")
-    skip_if_not_installed("base", minimum_version = "3.6.0")
     x <- c(1.83, 0.50, 1.62, 2.48, 1.68, 1.88, 1.55, 3.06, 1.30)
     y <- c(0.878, 0.647, 0.598, 2.05, 1.06, 1.29, 1.06, 3.14, 1.29)
 
-    rRB1 <- {
-      set.seed(1)
-      rank_biserial(x, y, paired = TRUE)
-    }
-    rRB2 <- {
-      set.seed(1)
-      rank_biserial(x - y)
-    }
+    rRB1 <- rank_biserial(x, y, paired = TRUE)
+    rRB2 <- rank_biserial(x - y)
+
     expect_equal(rRB1, rRB2)
     expect_equal(rRB1[[1]], 0.777, tolerance = 0.01)
-    expect_equal(rRB1$CI_low, 0.1977778, tolerance = 0.01)
-    expect_equal(rRB1$CI_high, 1, tolerance = 0.01)
+    expect_equal(rRB1$CI_low, 0.2953631, tolerance = 0.01)
+    expect_equal(rRB1$CI_high, 0.9441559, tolerance = 0.01)
 
 
     A <- c(48, 48, 77, 86, 85, 85, 16)
@@ -25,7 +18,7 @@ if (require("testthat") && require("effectsize")) {
 
 
     df <- data.frame(
-      outcome = c(x,y),
+      outcome = c(x, y),
       g = factor(rep(0:1, each = 9))
     )
     expect_equal(
@@ -52,8 +45,8 @@ if (require("testthat") && require("effectsize")) {
     E <- rank_epsilon_squared(x, g)
 
     expect_equal(E[[1]], 0.05934066, tolerance = 0.01)
-    expect_equal(E$CI_low, 0.01002212, tolerance = 0.01)
-    expect_equal(E$CI_high, 0.7408143, tolerance = 0.01)
+    expect_equal(E$CI_low, 0.004149302, tolerance = 0.01)
+    expect_equal(E$CI_high, 0.7596009, tolerance = 0.01)
 
     expect_equal(
       rank_epsilon_squared(x ~ g, ci = NULL),
