@@ -69,43 +69,28 @@ if (require("testthat") && require("effectsize")) {
     x <- cohens_d(wt ~ am, data = mtcars, pooled_sd = FALSE)
     expect_equal(colnames(x)[1], "Cohens_d")
     expect_equal(x[[1]], 1.934, tolerance = 0.001)
-    expect_equal(x$CI_low, 1.098798, tolerance = 0.001)
-    expect_equal(x$CI_high, 2.833495, tolerance = 0.001)
+    expect_equal(x$CI_low, 1.075151, tolerance = 0.001)
+    expect_equal(x$CI_high, 2.772516, tolerance = 0.001)
   })
 
   test_that("hedges_g (and other bias correction things", {
-    x <- hedges_g(wt ~ am, data = mtcars, correction = 1)
+    expect_warning(x <- hedges_g(wt ~ am, data = mtcars, correction = TRUE))
     expect_equal(colnames(x)[1], "Hedges_g")
     expect_equal(x[[1]], 1.844, tolerance = 0.001)
     expect_equal(x$CI_low, 1.004, tolerance = 0.001)
     expect_equal(x$CI_high, 2.664, tolerance = 0.001)
-
-    x <- hedges_g(wt ~ am, data = mtcars, correction = 2)
-    expect_equal(colnames(x)[1], "Hedges_g")
-    expect_equal(x[[1]], 1.786, tolerance = 0.001)
-    expect_equal(x$CI_low, 0.972, tolerance = 0.001)
-    expect_equal(x$CI_high, 2.579, tolerance = 0.001)
-
-    expect_warning(hedges_g(wt ~ am, data = mtcars, correction = TRUE))
-    expect_warning(cohens_d(wt ~ am, data = mtcars, correction = TRUE))
-    expect_warning(glass_delta(wt ~ am, data = mtcars, correction = TRUE, ci = NULL))
   })
 
   test_that("glass_delta", {
     # must be 2 samples
     expect_error(glass_delta(1:10))
-
-    skip_if_not_installed("boot")
-    skip_if_not_installed("base", minimum_version = "3.6.0")
-
     expect_error(glass_delta(wt, data = mtcars))
 
-    set.seed(8007)
     x <- glass_delta(wt ~ am, data = mtcars)
     expect_equal(colnames(x)[1], "Glass_delta")
     expect_equal(x[[1]], 2.200, tolerance = 0.001)
-    expect_equal(x$CI_low, 1.490089, tolerance = 0.001)
-    expect_equal(x$CI_high, 3.858925, tolerance = 0.001)
+    expect_equal(x$CI_low, 1.008664, tolerance = 0.001)
+    expect_equal(x$CI_high, 3.352597, tolerance = 0.001)
   })
 
 
@@ -132,5 +117,12 @@ if (require("testthat") && require("effectsize")) {
 
     # no length problems
     expect_error(cohens_d(mtcars$mpg - 23), regexp = NA)
+
+    # Missing factor levels: the actual levels in the data are 3rd and 4th
+    f <- factor(letters[1:2], levels = c("d", "e", "a", "b"))
+    f <- rep(f, each = 5)
+    y <- c(2, 4, 3, 5, 1, 7, 9, 8, 6, 1)
+    expect_error(d <- cohens_d(y, f), regexp = NA)
+    expect_true(attr(d, "pooled_sd"))
   })
 }
